/* <copyright                                       */
/* notice="cics-lm-source-asis"                     */
/* pids="5655EXP"                                   */
/* years="2012"                                     */
/* crc="955667377" >                                */
/* Licensed Materials - Property of IBM             */
/* 	5655EXP                                         */
/* 	(C) Copyright IBM Corp. 2012                    */
/* 	This source material is provided "AS-IS" under the terms and */
/* 	conditions of the IBM Customer Agreement and of the associated */
/* 	Licensed Program Specifications documentation for CICS Transaction */
/* 	Server for z/OS.                                */
/*                                                  */
/* 	The terms and conditions of this license permit users to modify this */
/* 	source material and DO NOT provide for any entitlement to defect */
/* 	correction.                                     */
/* </copyright>                                     */
package $packageName$;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import com.ibm.cics.core.comm.ConnectionConfiguration;
import com.ibm.cics.core.connections.AbstractConnectionCustomizer;
import com.ibm.cics.core.connections.IConnectionCustomizerListener;

public class TelnetConnectionCustomizer extends AbstractConnectionCustomizer {

	private Text timeoutText;
	private ConnectionConfiguration configuration;

	@Override
	public void createControl(Composite parent) {
		Composite c = new Composite(parent,SWT.NONE);
		c.setLayout(new GridLayout(3,false));
		new Label(c,SWT.NONE).setText("Connection");
		timeoutText = new Text(c,SWT.BORDER);
		new Label(c,SWT.NONE).setText("(ms) blank for infinite");
		
		// When the value of the text field changes - validate it
		timeoutText.addModifyListener(new ModifyListener(){
			@Override
			public void modifyText(ModifyEvent e) {
				for(IConnectionCustomizerListener listener: getListeners()){
					listener.propertyChanged(TelnetConnection.TIMEOUT_KEY, timeoutText.getText());
				}
			}			
		});
	}
	
	@Override
	public void updateCurrentConfiguration() {
		if(configuration != null){
			configuration.setExtendedAttribute(TelnetConnection.TIMEOUT_KEY, String.valueOf(timeoutText.getText()));
		}
	}

	@Override
	public void setConfiguration(ConnectionConfiguration connectionConfiguration) {
		configuration = connectionConfiguration;
		String timeoutValue = connectionConfiguration.getExtendedAttribute(TelnetConnection.TIMEOUT_KEY);
		if(timeoutValue != null){
			if(!timeoutText.getText().equals(timeoutValue)){
				timeoutText.setText(timeoutValue);
			}
		}
	}
	
	@Override
	public String validateEnteredData() {
		String text = timeoutText.getText();
		if(text != null && text.length() >0){
			try{
				Integer.valueOf(text);
			} catch (NumberFormatException e){
				return e.getMessage();
			}
		}
		return null;
	}

	@Override
	public void clear() {
		timeoutText.setText("");
	}

	@Override
	public void performDefaults() {
		timeoutText.setText("");
	}

}
